@@ -2,22 +2,30 @@
 from decimal import Decimal
 from distutils.version import LooseVersion
 from django.conf import settings
-from django.contrib.auth.models import User
+from django.contrib.auth.models import User, AnonymousUser
 from django.core.urlresolvers import reverse
 from django.db import models, transaction
 from django.db.models.aggregates import Sum
-from django.utils.translation import ugettext_lazy as _
-from django.core.urlresolvers import reverse
 from django.db.models.signals import pre_delete
-import django
+from django.utils.translation import ugettext_lazy as _
 from shop.models.cartmodel import CartItem
 from shop.models.productmodel import Product
 from shop.util.fields import CurrencyField
 from shop.util.loader import load_class
+import django
 
 
 class OrderManager(models.Manager):
     
+    def get_latest_for_user(self, user):
+        """
+        Returns the last Order (from a time perspective) a given user has placed.
+        """
+        if user and not isinstance(user, AnonymousUser):
+            return self.filter(user=user).order_by('-modified')[0]
+        else:
+            return None
+    
     @transaction.commit_on_success
     def create_from_cart(self, cart):
         """
@@ -45,7 +53,7 @@ class OrderManager(models.Manager):
         for label, value in cart.extra_price_fields:
             eoi = ExtraOrderPriceField()
             eoi.order = o
-            eoi.label = label
+            eoi.label = str(label)
             eoi.value = value
             eoi.save()
         
@@ -66,7 +74,7 @@ class OrderManager(models.Manager):
             for label, value in item.extra_price_fields:
                 eoi = ExtraOrderItemPriceField()
                 eoi.order_item = i
-                eoi.label = label
+                eoi.label = str(label)
                 eoi.value = value
                 eoi.save()
         return o
@@ -107,9 +115,6 @@ class Order(models.Model):
     order_subtotal = CurrencyField(verbose_name=_('Order subtotal'))
     order_total = CurrencyField(verbose_name='Order total')
     
-    payment_method = models.CharField(max_length=255, null=True,
-            verbose_name=_('Payment method'))
-    
     shipping_address_text = models.TextField(_('Shipping address'), blank=True, null=True)
     billing_address_text = models.TextField(_('Billing address'), blank=True, null=True)
 
