@@ -13,10 +13,12 @@ class FlatRateShipping(object):
     """
     url_namespace = 'flat'
     backend_name = 'Flat rate'
+    
 
     def __init__(self, shop):
         self.shop = shop # This is the shop reference, it allows this backend
         # to interact with it in a tidy way (look ma', no imports!)
+        self.rate = getattr(settings, 'SHOP_SHIPPING_FLAT_RATE', '10')
 
     def view_process_order(self, request):
         """
@@ -29,7 +31,7 @@ class FlatRateShipping(object):
         """
         self.shop.add_shipping_costs(self.shop.get_order(request),
                                      'Flat shipping',
-                                     Decimal(settings.SHOP_SHIPPING_FLAT_RATE))
+                                     Decimal(self.rate))
         return self.shop.finished(self.shop.get_order(request))
         # That's an HttpResponseRedirect
 
@@ -39,7 +41,7 @@ class FlatRateShipping(object):
         shipping will be (it's an example, alright)
         """
         ctx = {}
-        ctx.update({'shipping_costs':Decimal(settings.SHOP_SHIPPING_FLAT_RATE)})
+        ctx.update({'shipping_costs':Decimal(self.rate)})
         return render_to_response('shop/shipping/flat_rate/display_fees.html', ctx,
                                   context_instance=RequestContext(request))
 
