@@ -9,9 +9,8 @@ from shop.forms import BillingShippingForm
 from shop.models import AddressModel
 from shop.models.ordermodel import Order
 from shop.order_signals import completed
-from shop.util.address import (get_shipping_address_from_request, 
-    assign_address_to_request, get_billing_address_from_request, 
-    get_user_name_from_request)
+from shop.util.address import get_shipping_address_from_request, \
+    get_billing_address_from_request, assign_address_to_request
 from shop.util.cart import get_or_create_cart
 from shop.util.order import add_order_to_request, get_order_from_request
 from shop.views import ShopTemplateView, ShopView
@@ -24,16 +23,16 @@ class CheckoutSelectionView(ShopTemplateView):
         """
         Returns a dynamic ModelForm from the loaded AddressModel
         """
-        form_class = model_forms.modelform_factory(AddressModel, 
+        form_class = model_forms.modelform_factory(AddressModel,
                                                    exclude=['user_shipping', 'user_billing'])
         return form_class
-    
+
     def get_shipping_form_class(self):
         """
         Provided for extensibility.
         """
         return self._get_dynamic_form_class_from_factory()
-    
+
     def get_billing_form_class(self):
         """
         Provided for extensibility.
@@ -56,39 +55,37 @@ class CheckoutSelectionView(ShopTemplateView):
         """
         Initializes and handles the form for the shipping address.
         AddressModel is a model of the type defined in settings.SHOP_ADDRESS_MODEL.
-        
-        The trick here is that we generate a ModelForm for whatever model was 
+
+        The trick here is that we generate a ModelForm for whatever model was
         passed to us by the SHOP_ADDRESS_MODEL setting, and us this, prefixed, as
         the shipping address form. So this can be as complex or as simple as one wants.
-        
-        Subclasses of this view can obviously override this method and return any 
+
+        Subclasses of this view can obviously override this method and return any
         other form instead.
         """
         # Try to get the cached version first.
         form = getattr(self, '_shipping_form', None)
-        initial = {'name':get_user_name_from_request(self.request)}
         if not form:
             # Create a dynamic Form class for the model specified as the address model
             form_class = self.get_shipping_form_class()
-            
+
+            # Try to get a shipping address instance from the request (user or session))
+            shipping_address = get_shipping_address_from_request(self.request)
             if self.request.method == "POST":
-                form = form_class(self.request.POST, prefix="ship")
+                form = form_class(self.request.POST, prefix="ship", instance=shipping_address)
             else:
-                # Try to get a shipping address instance from the request (user or session))
-                shipping_address = get_shipping_address_from_request(self.request)
                 # We should either have an instance, or None
                 if not shipping_address:
                     # The user or guest doesn't already have a favorite address.
                     # Instanciate a blank one, and use this as the default value for
                     # the form.
                     shipping_address = AddressModel()
-                    # Make our new address the default for the User or Guest.
-                    assign_address_to_request(self.request, shipping_address, shipping=True)
-                    
-                form = form_class(instance=shipping_address, prefix="ship", initial=initial)
+                
+                # Instanciate the form
+                form = form_class(instance=shipping_address, prefix="ship")
             setattr(self, '_shipping_form', form)
         return form
-    
+
     def get_billing_address_form(self):
         """
         Initializes and handles the form for the shipping address.
@@ -96,33 +93,28 @@ class CheckoutSelectionView(ShopTemplateView):
         """
         # Try to get the cached version first.
         form = getattr(self, '_billing_form', None)
-        initial = {'name':get_user_name_from_request(self.request)}
         if not form:
-            
             # Create a dynamic Form class for the model specified as the address model
             form_class = model_forms.modelform_factory(AddressModel,
                                                        exclude=['user_shipping', 'user_billing'])
+            
+            # Try to get a shipping address instance from the request (user or session))
+            billing_address = get_billing_address_from_request(self.request)
             if self.request.method == "POST":
-                form = form_class(self.request.POST, prefix="bill")
+                form = form_class(self.request.POST, prefix="bill", instance=billing_address)
             else:
-                # Try to get a shipping address instance from the request (user or session))
-                billing_address = get_billing_address_from_request(self.request)
                 # We should either have an instance, or None
                 if not billing_address:
                     # The user or guest doesn't already have a favorite address.
                     # Instansiate a blank one, and use this as the default value for
                     # the form.
                     billing_address = AddressModel()
-                    # Make our new address the default for the User or Guest.
-                    assign_address_to_request(self.request, billing_address, shipping=False)
-                    
-                form = form_class(instance=billing_address, prefix="bill", initial=initial)
                 
-            
+                #Instanciate the form
+                form = form_class(instance=billing_address, prefix="bill")
             setattr(self, '_billing_form', form)
-            
         return form
-            
+
     def get_billing_and_shipping_selection_form(self):
         """
         Get (and cache) the BillingShippingForm instance
@@ -132,7 +124,7 @@ class CheckoutSelectionView(ShopTemplateView):
             if self.request.method == 'POST':
                 form = BillingShippingForm(self.request.POST)
             else:
-                form = BillingShippingForm
+                form = BillingShippingForm()
             self._billingshipping_form = form
         return form
 
@@ -150,20 +142,25 @@ class CheckoutSelectionView(ShopTemplateView):
         shipping_form = self.get_shipping_address_form()
         billing_form = self.get_billing_address_form()
         if shipping_form.is_valid() and billing_form.is_valid():
-            
+
             # Add the address to the order
             shipping_address = shipping_form.save()
             billing_address = billing_form.save()
             order = self.create_order_object_from_cart()
-            
+
             self.save_addresses_to_order(order, shipping_address, billing_address)
             
+            # The following marks addresses as being default addresses for shipping
+            # and billing. For more options (amazon style), we should remove this 
+            assign_address_to_request(self.request, shipping_address, shipping=True)
+            assign_address_to_request(self.request, billing_address, shipping=False)
+
             billingshipping_form = self.get_billing_and_shipping_selection_form()
             if billingshipping_form.is_valid():
                 self.request.session['payment_backend'] = billingshipping_form.cleaned_data['payment_method']
                 self.request.session['shipping_backend'] = billingshipping_form.cleaned_data['shipping_method']
                 return HttpResponseRedirect(reverse('checkout_shipping'))
-        
+
         return self.get(self, *args, **kwargs)
 
     def get_context_data(self, **kwargs):
@@ -190,9 +187,13 @@ class ThankYouView(ShopTemplateView):
 
         # Set the order status:
         order = get_order_from_request(self.request)
-        order.status = Order.COMPLETED
-        order.save()
-        completed.send(sender=self, order=order)
+        if order:
+            order.status = Order.COMPLETED
+            order.save()
+            completed.send(sender=self, order=order)
+        else:
+            order = Order.objects.get_latest_for_user(self.request.user)
+        ctx.update({'order': order,})
 
         # Empty the customers basket, to reflect that the purchase was completed
         cart_object = get_or_create_cart(self.request)
@@ -207,7 +208,7 @@ class ShippingBackendRedirectView(ShopView):
             return HttpResponseRedirect(reverse(backend_namespace))
         except KeyError:
             return HttpResponseRedirect(reverse('cart'))
-        
+
 class PaymentBackendRedirectView(ShopView):
     def get(self, *args, **kwargs):
         try:
